#
# spec file for package resources
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 mantarimay
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without test
%define appid net.nokyan.Resources
Name:           resources
Version:        1.6.0
Release:        1.1
Summary:        Monitor your system processes
License:        GPL-3.0-or-later
URL:            https://github.com/nokyan/resources
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  appstream-glib
BuildRequires:  cargo-packaging
BuildRequires:  desktop-file-utils
BuildRequires:  meson
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.5.0
Requires:       dmidecode
Requires:       polkit

%description
Resources is a simple yet powerful monitor for your system resources and
processes, written in Rust and using GTK 4 and libadwaita for its GUI.

%lang_package

%prep
%autosetup -a1

%build
%meson -Dprofile=default
%meson_build

%install
%meson_install

%find_lang %{name}

%if %{with test}
%check
%meson_test
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/%{name}/
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}*.svg
%{_datadir}/metainfo/%{appid}.metainfo.xml
%exclude %{_datadir}/polkit-1/actions/%{appid}.policy
%{_libexecdir}/%{name}/

%files lang -f %{name}.lang

%changelog
* Fri Aug 23 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
  Update to version 1.6.0
  + Bug fixes
  - Multiple dialogs (e. g. Settings dialog) could be shown at
    the same time
  - Resources could freeze sometimes after the device wakes up
    from sleep
  - Apps installed in local folders (e. g. /usr/local/share) were
    not recognized
  - Sidebar ordering could get messed up when a new drive or
    network interface was detected
  - Accessibility hints and tooltips were not translatable
  - Resources could not detect power usage of some batteries
  + New features
  - Dialog for changing a process’ priority and CPU affinity
  - Resources and resources-processes now accept commandline
    arguments to help with debugging
  - Context menus for items in the Apps and Processes views
  + Improvements
  - Graphs now have rounded corners
  - Memory usage over time has been reduced
  - Vastly improved debug messages
  - Improved app detection
  - Debug messages are disabled per default when using the
    release profile (or just use env RUST_LOG=resources=debug)
* Sun Aug 18 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.5.1
  + Bug fixes:
  - AMD GPU usage could be displayed to be higher than 100 %%
  - Resources detected HID batteries resulting in unnecessary battery
    pages with little to no information
  - AMD GPU power usage couldn’t be determined sometimes
  + Improvements:
  - Smaller GNOME Circle related fixes and improvements
* Sun Jun 23 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Add meson test to validate files
* Sun Jun 23 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.5.0
  + Bug fixes
  - If the Processes view was the last opened view and the
    “Show search fields on launch” setting was enabled, the
    search bar was not automatically focused
  - Graphs in the sidebar were reset when a drive or network
    interface was added or removed
  - App icons were not shown for user-wide installed Flatpaks
  - The calculated amount of logical CPUs was wrong for systems
    with multiple CPU sockets
  + New features
  - Resources can now monitor connected batteries
  - CPU usage normalization can now be toggled off
  - Total read and write stats for drives
  + Improvements
  - Graph colors have been revamped to avoid low contrast
    situations and improve consistency within views
  - Some keyboard shortcuts were changed to avoid clashes with
    standard shortcuts
  - More stability when performance statistics could not be
    determined
  - Some entries in the settings dialog now have subtitles
  - If a drive has no model name, its block device name will now
    be shown in the titlebar
  - Small accessibility improvements
* Sun Dec 24 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
